==> 1.0.2_20240315_release.zip: app/service/admin/S_adminMenu.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_adminMenu;


class S_adminMenu
{
    public $D_adminMenu;

    public function __construct()
    {
        $this->D_adminMenu = new D_adminMenu();
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->D_adminMenu->store($paramObj);
    }

    /**
     * 记录数据
     * @param string $paramObj
     * @return array
     */
    public function record($paramObj=""){
        return $this->D_adminMenu->record($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->D_adminMenu->info($paramObj);
    }
    /**
     * 获取ids数据详情
     * @param string $paramObj
     * @return array
     */
    public function infos($paramObj=""){
        return $this->D_adminMenu->infos($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->D_adminMenu->update($paramObj);
    }

    /**
     * 更新数据 for 模块管理
     * @param string $paramObj
     * @return array
     */
    public function updateForModule($paramObj=""){
        return $this->D_adminMenu->updateForModule($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->D_adminMenu->delete($paramObj);
    }
    /**
     * 数据指定插件
     * @param string $paramObj
     * @return array
     */
    public function deletePlugins($paramObj=""){
        return $this->D_adminMenu->deletePlugins($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }

    /**
     * 分页列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->D_adminMenu->listData($paramObj);
    }

    /**
     * 获取全部广告位信息
     * @param string $paramObj
     * @return array
     */
    public function getAll($paramObj=""){
        return $this->D_adminMenu->getAll($paramObj);
    }
}

==> 1.0.20_20240718_release.zip: app/service/admin/S_adminMenu.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_adminMenu;


class S_adminMenu
{
    public $D_adminMenu;

    public function __construct()
    {
        $this->D_adminMenu = new D_adminMenu();
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->D_adminMenu->store($paramObj);
    }

    /**
     * 记录数据
     * @param string $paramObj
     * @return array
     */
    public function record($paramObj=""){
        return $this->D_adminMenu->record($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->D_adminMenu->info($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function infoByUnique($paramObj=""){
        return $this->D_adminMenu->infoByUnique($paramObj);
    }

    /**
     * 获取ids数据详情
     * @param string $paramObj
     * @return array
     */
    public function infos($paramObj=""){
        return $this->D_adminMenu->infos($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->D_adminMenu->update($paramObj);
    }

    /**
     * 更新数据 for 模块管理
     * @param string $paramObj
     * @return array
     */
    public function updateForModule($paramObj=""){
        return $this->D_adminMenu->updateForModule($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->D_adminMenu->delete($paramObj);
    }
    /**
     * 数据指定插件
     * @param string $paramObj
     * @return array
     */
    public function deletePlugins($paramObj=""){
        return $this->D_adminMenu->deletePlugins($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }

    /**
     * 分页列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->D_adminMenu->listData($paramObj);
    }

    /**
     * 获取全部广告位信息
     * @param string $paramObj
     * @return array
     */
    public function getAll($paramObj=""){
        return $this->D_adminMenu->getAll($paramObj);
    }

    /**
     * 置顶操作
     * @param string $paramObj
     * @return array
     */
    public function topOperation($paramObj=""){
        return $this->D_adminMenu->topOperation($paramObj);
    }

    /**
     * 获取 max isTop值
     * @param string $paramObj
     * @return array
     */
    public function getMaxIsTop($paramObj=""){
        return $this->D_adminMenu->getMaxIsTop($paramObj);
    }
}
